#!/bin/bash
#
# Christian Benjamin Ries, November 2010
# Christian_Benjamin.Ries@fh-bielefeld.de
# University of Applied Sciences Bielefeld, Germany
# http://www.christianbenjaminries.de
# License: GNU GPL
#

function usage() {
  echo "Usage: $0 -c COUNT -v FILE -m MODE [-r]"
  echo "Description:"
  echo "     -c    Define the number of images in one zip archive."
  echo "     -v    File name of the video input."
  echo "     -m    edge | normalize | oil | shade | negate"
  echo "     -r    Removes all archive or sequence files and exits after delete."
  exit 1
}

if [ $# -le 5 ]
	then
	usage
fi

while getopts  "c:v:m:r" flag
do
  case "$flag" in
    c) COUNT=$OPTARG 
		;;
    v) VIDEOIN=$OPTARG 
		;;
    m) MODE=$OPTARG 
		;;
		r)
			rm -rf sequences/
			rm -rf archives/ 
			exit 0
		;;
    *) usage ;;
  esac
done

if ["${#COUNT}" -eq "0"]
	then 
		usage 
fi
if ["${#VIDEOIN}" -le "0"]
	then 
		usage 
fi
if ["${#MODE}" -le "0"]
	then 
		usage 
fi

source make_configuration

mkdir -p sequences/
mkdir -p archives/

ffmpeg -i ${VIDEOIN} sequences/${FORMAT}

declare -a IMAGES

let count=0
let countArchive=0
for file in sequences/*${MODE}*
do
	if [ ! "${file}" == "." ]
		then
			if [ ! "${file}" == ".." ]
				then
					IMAGES[$count]=`basename ${file}`
					((count++))
					if [ ${count} -ge ${COUNT} ]
						then
							cd sequences/
							((countArchive++))
							ARCHIVENAME=`printf "../archives/${FORMAT}.zip" ${countArchive}`
							
							zip ${ARCHIVENAME} ${IMAGES[@]}

							echo ${ARCHIVENAME}
							let count=0
							cd -
					fi
			fi
	fi
done

